@@ -14,7 +14,7 @@ class TQResizeEvent;
 
 class K9Mplayer : public MPlayer
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 private:
   TDEProcess    *m_process;
