@@ -34,7 +34,7 @@ extern "C" {
 
 class k9AviDecode : public TQObject
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
     k9AviDecode(TQObject *parent = 0, const char *name = 0);
