@@ -22,7 +22,7 @@
 class k9Title;
 class k9AviFile : public TQObject
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
     k9AviFile(k9Title *parent = 0, const char *name = 0);
