@@ -24,7 +24,7 @@ class k9AviFile;
 class k9MenuButton;
 class k9MenuEdit;
 class k9Import : public import {
-    Q_OBJECT
+    TQ_OBJECT
   
 private:
     TQListViewItem *m_root;
