@@ -25,7 +25,7 @@ class k9MenuEditor;
 
 
 class k9MenuEdit : public menuEdit {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     enum eFormat {PAL=1,NTSC=2};
