@@ -22,7 +22,7 @@ class k9MenuButton;
 class k9MenuEdit;
 class k9CanvasSelection;
 class k9MenuEditor : public TQCanvasView {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
