@@ -21,7 +21,7 @@
 class k9Import;
 class k9NewTitle : public newTitle
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 private:
    k9Import *m_k9Import;
