@@ -26,7 +26,7 @@
   *@author 
   */
 class k9CdDrive : public TQObject {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     k9CdDrive();
@@ -46,7 +46,7 @@ private:
 };
 
 class k9CdDrives : public TQObject  {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     k9CdDrives();
