@@ -368,7 +368,7 @@ int k9vamps::check_video_packet (uchar *ptr) {
 
     if (ptr [7]) {
         if ((ptr [7] & 0xc0) != 0xc0)
-           qDebug ("%s", (TQString("First video packet in sequence starting at %1 misses PTS or DTS, flags=%2").arg(rtell (ptr)).arg(ptr [7])).ascii());
+           tqDebug ("%s", (TQString("First video packet in sequence starting at %1 misses PTS or DTS, flags=%2").arg(rtell (ptr)).arg(ptr [7])).ascii());
         else {
             sequence_header_code  = (uint32_t) (ptr [6 + 3 + ptr [8] + 0]) << 24;
             sequence_header_code |= (uint32_t) (ptr [6 + 3 + ptr [8] + 1]) << 16;
@@ -399,7 +399,7 @@ int k9vamps::check_video_packet (uchar *ptr) {
         pad_packet_start_code |= (uint32_t) (ptr [3]);
 
         if (pad_packet_start_code != 0x000001be)
-            qDebug ("%s", (TQString("Bad padding packet start code at %1: %2").arg(rtell (ptr + vid_packet_length)).arg(pad_packet_start_code)).ascii());
+            tqDebug ("%s", (TQString("Bad padding packet start code at %1: %2").arg(rtell (ptr + vid_packet_length)).arg(pad_packet_start_code)).ascii());
         else {
             pad_packet_length  = ptr [4] << 8;
             pad_packet_length |= ptr [5];
@@ -409,7 +409,7 @@ int k9vamps::check_video_packet (uchar *ptr) {
 
     // length of video packet plus padding packet must always match sector size
     if (14 + vid_packet_length + pad_packet_length != SECT_SIZE)
-        qDebug ("%s", (TQString("Bad video packet length at %1: %2").arg(rtell (ptr)).arg(vid_packet_length)).ascii());
+        tqDebug ("%s", (TQString("Bad video packet length at %1: %2").arg(rtell (ptr)).arg(vid_packet_length)).ascii());
 
     return rc;
 }
@@ -474,12 +474,12 @@ int k9vamps::requant (uchar *dst, uchar *src, int n, float fact) {
 
 
 //    if (rv>n)
-//        qDebug("requant error");
+//        tqDebug("requant error");
 
     double realrqtfact=(double)(vin_bytes) / (double)(vout_bytes+rv);
     avgdiff = ((m_avgfact) /realrqtfact);
 
-    //qDebug ("factor : " +TQString::number(m_avgfact) +"  --> " +TQString::number((float)n/(float)rv) +" avgdiff : " + TQString::number(avgdiff) +" rqt_visize :" +TQString::number(m_requant->rqt_visize) +" ps_size :" +TQString::number(ps_size) + " vin_bytes :" + TQString::number(vin_bytes)) ;
+    //tqDebug ("factor : " +TQString::number(m_avgfact) +"  --> " +TQString::number((float)n/(float)rv) +" avgdiff : " + TQString::number(avgdiff) +" rqt_visize :" +TQString::number(m_requant->rqt_visize) +" ps_size :" +TQString::number(ps_size) + " vin_bytes :" + TQString::number(vin_bytes)) ;
 
     return rv;
 
