@@ -412,7 +412,7 @@ void k9DVDAuthor::author() {
 
     if ( ! k9Tools::checkProgram("dvdauthor")) {
 	KMessageBox::error (tqApp->mainWidget(),i18n("Unable to run %1").arg("dvdauthor") , i18n("authoring"));	
-	error = TRUE;
+	error = true;
 	return;
     }
 
