@@ -35,7 +35,7 @@
   */
 
 class k9DVDAuthor : public TQObject  {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	k9DVDAuthor(TQObject *DVDStruct,const char* name=0,const TQStringList& args=0) ;
