@@ -23,7 +23,7 @@ class k9MP4Dlg;
 	@author Jean-Michel PETIT <k9copy@free.fr>
 */
 class k9MP4Enc : public TQObject {
-    Q_OBJECT
+    TQ_OBJECT
   
 private:
     k9Process *m_process;
