@@ -21,7 +21,7 @@
 #include "k9drawimage.h"
 
 class k9Progress : public Progress {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
