@@ -31,7 +31,7 @@ class kDecMPEG2;
 
 class k9SaveImage : public TQObject,TQThread
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
     k9SaveImage();
