@@ -57,9 +57,9 @@ k9Copy::k9Copy()
 
     // and a status bar
     statusBar()->show();
-    statusBar()->insertFixedItem("",sbFactor,TRUE);
+    statusBar()->insertFixedItem("",sbFactor,true);
     statusBar()->setItemFixed(sbFactor,100);
-    statusBar()->insertItem("",sbMessage,1,FALSE);
+    statusBar()->insertItem("",sbMessage,1,false);
     statusBar()->setItemAlignment(sbMessage,AlignLeft | AlignVCenter);
 
     // Apply the create the main window and ask the mainwindow to
@@ -258,7 +258,7 @@ void k9Copy::setupActions() {
     KStdAction::configureToolbars(this, TQ_SLOT(optionsConfigureToolbars()), actionCollection());
 
 
-    setStandardToolBarMenuEnabled(TRUE);
+    setStandardToolBarMenuEnabled(true);
     createStandardStatusBarAction();
 
     PlayTitleAction = new TDEAction(i18n("Play title"), 0,
