@@ -128,7 +128,7 @@ void k9GLWidget::draw() {
 
 
 void k9GLWidget::initializeGL() {
-    setAutoBufferSwap(FALSE);
+    setAutoBufferSwap(false);
     glClearColor (0.0, 0.0, 0.0, 0.0);
     glShadeModel(GL_FLAT);
     glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
