@@ -17,7 +17,7 @@
 
 class k9prefDVD : public prefDVD
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
