@@ -17,7 +17,7 @@
 #include <tqradiobutton.h>
 #include <tqcombobox.h>
 #include <tqcheckbox.h>
-#include <klocale.h>
+#include <tdelocale.h>
 
 k9prefPreview::k9prefPreview(TQWidget* parent, const char* name, WFlags fl)
 : prefPreview(parent,name,fl)
