@@ -66,8 +66,8 @@ k9settings::k9settings(TQWidget *parent,const TQString &caption):  KDialogBase (
     grid->addWidget(m_prefAuthor,0,0);
 
 
-    connect(this, TQT_SIGNAL(okClicked()), TQT_SLOT(slotOkClicked()));
-    connect(this, TQT_SIGNAL(applyClicked()), TQT_SLOT(slotApplyClicked()));
+    connect(this, TQ_SIGNAL(okClicked()), TQ_SLOT(slotOkClicked()));
+    connect(this, TQ_SIGNAL(applyClicked()), TQ_SLOT(slotApplyClicked()));
 }
 
 void k9settings::slotOkClicked() {
