@@ -25,7 +25,7 @@
 	@author Jean-Michel PETIT <k9copy@free.fr>
 */
 class k9settings:public KDialogBase{
-Q_OBJECT
+TQ_OBJECT
   
 public:
     k9settings(TQWidget *parent,const TQString &caption);
